Documentation
¶
Overview ¶
Package case2 is a generated GoMock package.
Index ¶
- Constants
- func Run(ctx context.Context, app *App) error
- type App
- type FooReq
- type MockTest1Component
- type MockTest1ComponentFooCall
- func (c *MockTest1ComponentFooCall) Do(f func(context.Context, *FooReq) error) *MockTest1ComponentFooCall
- func (c *MockTest1ComponentFooCall) DoAndReturn(f func(context.Context, *FooReq) error) *MockTest1ComponentFooCall
- func (c *MockTest1ComponentFooCall) Return(arg0 error) *MockTest1ComponentFooCall
- type MockTest1ComponentMockRecorder
- type MockTest2Component
- type MockTest2ComponentFooCall
- func (c *MockTest2ComponentFooCall) Do(f func(context.Context, *FooReq) error) *MockTest2ComponentFooCall
- func (c *MockTest2ComponentFooCall) DoAndReturn(f func(context.Context, *FooReq) error) *MockTest2ComponentFooCall
- func (c *MockTest2ComponentFooCall) Return(arg0 error) *MockTest2ComponentFooCall
- type MockTest2ComponentMockRecorder
- type Test1Component
- type Test2Component
Constants ¶
const ( // Test1Component_ComponentName is the full name of the component [Test1Component]. Test1Component_ComponentName = "github.com/go-kod/kod/tests/case2/Test1Component" // Test1Component_Foo_FullMethodName is the full name of the method [test1Component.Foo]. Test1Component_Foo_FullMethodName = "github.com/go-kod/kod/tests/case2/Test1Component.Foo" // Test2Component_ComponentName is the full name of the component [Test2Component]. Test2Component_ComponentName = "github.com/go-kod/kod/tests/case2/Test2Component" // Test2Component_Foo_FullMethodName is the full name of the method [test2Component.Foo]. Test2Component_Foo_FullMethodName = "github.com/go-kod/kod/tests/case2/Test2Component.Foo" )
Full method names for components.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type MockTest1Component ¶
type MockTest1Component struct {
// contains filtered or unexported fields
}
MockTest1Component is a mock of Test1Component interface.
func NewMockTest1Component ¶
func NewMockTest1Component(ctrl *gomock.Controller) *MockTest1Component
NewMockTest1Component creates a new mock instance.
func (*MockTest1Component) EXPECT ¶
func (m *MockTest1Component) EXPECT() *MockTest1ComponentMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockTest1ComponentFooCall ¶
MockTest1ComponentFooCall wrap *gomock.Call
func (*MockTest1ComponentFooCall) Do ¶
func (c *MockTest1ComponentFooCall) Do(f func(context.Context, *FooReq) error) *MockTest1ComponentFooCall
Do rewrite *gomock.Call.Do
func (*MockTest1ComponentFooCall) DoAndReturn ¶
func (c *MockTest1ComponentFooCall) DoAndReturn(f func(context.Context, *FooReq) error) *MockTest1ComponentFooCall
DoAndReturn rewrite *gomock.Call.DoAndReturn
func (*MockTest1ComponentFooCall) Return ¶
func (c *MockTest1ComponentFooCall) Return(arg0 error) *MockTest1ComponentFooCall
Return rewrite *gomock.Call.Return
type MockTest1ComponentMockRecorder ¶
type MockTest1ComponentMockRecorder struct {
// contains filtered or unexported fields
}
MockTest1ComponentMockRecorder is the mock recorder for MockTest1Component.
func (*MockTest1ComponentMockRecorder) Foo ¶
func (mr *MockTest1ComponentMockRecorder) Foo(ctx, req any) *MockTest1ComponentFooCall
Foo indicates an expected call of Foo.
type MockTest2Component ¶
type MockTest2Component struct {
// contains filtered or unexported fields
}
MockTest2Component is a mock of Test2Component interface.
func NewMockTest2Component ¶
func NewMockTest2Component(ctrl *gomock.Controller) *MockTest2Component
NewMockTest2Component creates a new mock instance.
func (*MockTest2Component) EXPECT ¶
func (m *MockTest2Component) EXPECT() *MockTest2ComponentMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockTest2ComponentFooCall ¶
MockTest2ComponentFooCall wrap *gomock.Call
func (*MockTest2ComponentFooCall) Do ¶
func (c *MockTest2ComponentFooCall) Do(f func(context.Context, *FooReq) error) *MockTest2ComponentFooCall
Do rewrite *gomock.Call.Do
func (*MockTest2ComponentFooCall) DoAndReturn ¶
func (c *MockTest2ComponentFooCall) DoAndReturn(f func(context.Context, *FooReq) error) *MockTest2ComponentFooCall
DoAndReturn rewrite *gomock.Call.DoAndReturn
func (*MockTest2ComponentFooCall) Return ¶
func (c *MockTest2ComponentFooCall) Return(arg0 error) *MockTest2ComponentFooCall
Return rewrite *gomock.Call.Return
type MockTest2ComponentMockRecorder ¶
type MockTest2ComponentMockRecorder struct {
// contains filtered or unexported fields
}
MockTest2ComponentMockRecorder is the mock recorder for MockTest2Component.
func (*MockTest2ComponentMockRecorder) Foo ¶
func (mr *MockTest2ComponentMockRecorder) Foo(ctx, req any) *MockTest2ComponentFooCall
Foo indicates an expected call of Foo.
type Test1Component ¶
type Test1Component interface {
// Foo is implemented by [test1Component.Foo]
Foo(ctx context.Context, req *FooReq) error
}
Test1Component is implemented by [test1Component], which can be mocked with NewMockTest1Component.
type Test2Component ¶
type Test2Component interface {
// Foo is implemented by [test2Component.Foo]
Foo(ctx context.Context, req *FooReq) error
}
Test2Component is implemented by [test2Component], which can be mocked with NewMockTest2Component.